local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

local StatBuffs = {
	1126--[[Mark of the Wild]],
	115921--[[Legacy of the Emperor]],
	20217--[[Blessing of Kings]],
}

a.spells["Auto Attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Shoot"] = {
	ID = 3018--[[Shoot]],
	EnemyTargetNeeded = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC and not s.Shooting()
	end,
}

a.spells["Purifying Brew"] = {
	ID = 119582--[[Purifying Brew]],
	CheckFirst = function(z)
		return (s.DebuffStack(124274--[[Moderate Stagger]], "player") ~= 0) or (s.DebuffStack(124273--[[Heavy Stagger]], "player") ~= 0)
	end,
}

a.spells["Blackout Kick"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	EnemyTargetNeeded = 1,
	Melee = 1,
	EarlyRefresh = 0.5,
	CheckFirst = function(z)
		return x.NoCC
	end,
}

a.spells["Zen Sphere"] = {
	ID = 124081--[[Zen Sphere]],
	MyBuff = 124081--[[Zen Sphere]],
	BuffUnit = "player",
	NoRangeCheck = 1,
	Unit = "player",
	EarlyRefresh = 1,
	CheckFirst = function(z)
		return (s.MyBuffDuration(115307--[[Shuffle]], "player") > 1.5) or (s.Power("player", 12) >= 4)
	end,
}

a.spells["Breath of Fire"] = {
	ID = 115181--[[Breath of Fire]],
	MyDebuff = 115181--[[Breath of Fire]],
	RequireDebuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = 1,
	EarlyRefresh = 0.5,
	CheckFirst = function(z)
		return x.NoCC and ((s.MyBuffDuration(115307--[[Shuffle]], "player") > 1.5) or (s.Power("player", 12) >= 4))
	end,
}

a.spells["Keg Smash"] = {
	ID = 121253--[[Keg Smash]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and (s.Power("player", 12) <= s.MaxPower("player", 12) - 2)
	end,
}

a.spells["Expel Harm"] = {
	ID = 115072--[[Expel Harm]],
	CheckFirst = function(z)
		return s.HealthPercent("player") < 80
	end,
}
a.spells["Jab"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC and (s.Power("player", 12) <= s.MaxPower("player", 12) - 1)
	end,
}

a.spells["Guard"] = {
	ID = 115295--[[Guard]],
	CheckFirst = function(z)
		return s.HealthPercent("player") < 75
	end,
}

a.spells["Tiger Palm"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	CheckFirst = function(z)
		return x.NoCC
	end,
}

a.spells["Elusive Brew"] = {
	ID = 115308--[[Elusive Brew]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	FlashColor = "Yellow",
	CheckFirst = function(z)
		return s.MyBuffStack(115308--[[Elusive Brew]], "player") >= 3
	end,
}

a.spells["Fortifying Brew"] = {
	ID = 115203--[[Fortifying Brew]],
	FlashColor = "Red",
	CheckFirst = function(z)
		return s.HealthPercent("player") < 50
	end,
}

a.spells["Legacy of the Emperor"] = {
	ID = 115921--[[Legacy of the Emperor]],
	Buff = StatBuffs,
	BuffUnit = "party",
	FlashColor = "Green",
}

a.spells["Spear Hand Strike"] = {
	ID = 116705--[[Spear Hand Strike]],
	EnemyTargetNeeded = 1,
	Interrupt = 1,
	FlashColor = "Aqua",
}

a.spells["Provoke"] = {
	ID = 115546--[[Provoke]],
	EnemyTargetNeeded = 1,
	CheckFirst = function(z)
		return s.Form(115069--[[Stance of the Sturdy Ox]]) and x.NoCC and x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 )
	end,
	FlashColor = "Purple",
}